# Oisín: Wave Function Collapse for poetry

This is inpv's fork of mewo2's code for performing the [WaveFunctionCollapse][wfc] algorithm on poems. It mashes up sentence fragments from a given corpus to produce poems with fixed metric forms. The output can look like this:

![Demo GIF](output/test.gif?raw=true)

It is named after Oisín, son of Fionn mac Cumhaill, the great poet-warrior of Irish mythology. He famously married Niamh, daughter of the sea god Manannán mac Lir, and disappeared over the waves to Tír na nÓg. Waves, poetry, etc, you get it.

The name is pronounced [ɔ'ʃiːnʲ] (ush-EEN).

## Support, licensing, ongoing development

_Original author (mewo2)_:

This is experimental code, for an experiment that I never really finished.

The code is available under the [MIT license](LICENSE.md), so you can fork it,
improve it, learn from it, build upon it. However, I have no interest in
maintaining it as an ongoing open source project, nor in providing support for
it. Pull requests will probably be either ignored or closed.

If you do make something interesting with this code, please do still let me know! I'm sorry that I can't provide any support, but I am still genuinely interested in seeing creative applications of the code.

_inpv_:

I plan on making this code more usable as a Python module in the future, unveiling its hidden possibilities.

[wfc]: https://github.com/mxgmn/WaveFunctionCollapse